diff --git a/index.ts b/index.ts
index 0f0a0be..e9f9201 100644
--- a/index.ts
+++ b/index.ts
@@ -579,7 +579,7 @@ async function runPlugin(ctx: any, options: any, dataDir: string) {
: []
if (childTools.length > 0) {
// Execute has child tool calls — show only the children, skip execute
for (const child of childTools) {
parts.push(`\n🔧 ${child.name}
\n\n`)
parts.push(`Args:\n\`\`\`\n${child.args}\n\`\`\`\n\n`)
@@ -590,6 +590,12 @@ async function runPlugin(ctx: any, options: any, dataDir: string) {
}
parts.push(` `)
}
+ // Show execute result as a separate spoiler after all child tools
+ if (executeTool?.result) {
+ parts.push(`\n🔧 execute
\n\n`)
+ parts.push(`Result:\n\`\`\`\n${executeTool.result}\n\`\`\`\n\n`)
+ parts.push(` `)
+ }
} else {
// No child tool calls — show tools normally (including execute as-is)
for (const tool of step.tools) {
@@ -579,7 +579,7 @@ async function runPlugin(ctx: any, options: any, dataDir: string) {
: []
if (childTools.length > 0) {
- // Execute has child tool calls — show only the children, skip execute
+ // Execute has child tool calls — show children, then execute result separately
for (const child of childTools) {
parts.push(`\n🔧 ${child.name}